	Rem -- This script will illustrate how to extract and process text of the printed output.	
	Rem -- We here need the "invoice number from print data" for attaching ZUGFeRD XMLs to PDF/A1b file!
	Rem -- We then generate a well formed PDF/A-3U ZUGFeRD PDF with the free Mustang-CLI Java Library.
	
	
	Rem -- global vars
    Dim invoice_number
	Dim showmypdf
	Dim printername
	Dim global_success
    Dim RenameZUGFeRDPDFToOriginPDFName
	Dim delMyOriginPDF
	
	
	Rem -- *****************************************************
	Rem -- GLOBAL Script Configuration setting variables
	Rem -- *****************************************************
	
	Rem -- Note: If you are using our pdf printer as "shared pdf network printer",
	Rem -- You should also set the variable showmypdf fix to "no"
	Rem -- Remember: You surely need that on a printer server environment!
	showmypdf = "yes"
			
	Rem -- The final ZUGFeRD PDF outputfile will always get a *.zuferd.pdf file extension!
	Rem -- The original pdf file can be delete if you wish this.
	delMyOriginPDF = "yes"
	
	Rem -- Do you like no *.zugferd.pdf, and the ZUGFeRD conformed pdf should name as the original pdf,
	Rem -- so set this VAR to yes.
	RenameZUGFeRDPDFToOriginPDFName = "yes"
					
	Rem -- *****************************************************
	Rem -- GLOBAL Script Configuration setting variables / END
	Rem -- *****************************************************

				
    Sub OnConfigLoaded()
		
		printername = Context("PrinterName")

		Rem -- Modify the configuration to extract text from the printer
        Rem -- output.
		
		Context("Config")("extracttext") = "yes"
		
    End Sub
	
	Sub OnMacrosApplied
		
		context("Config")("rememberlastoptionset") = "no"  
		context("Config")("format") = "pdfa1b"
		context("Config")("compatibilitylevel") = "1.7"
			
		Rem -- 7-PDF Printer Process must not lock the pdf, so we disable this feature and use a ShellExecute at the end
		context("Config")("showpdf") = "no"
		Rem -- Important: Let the config value be always "no" here!
			
	End Sub
     
    Sub OnPreprocessText()
		Const ForReading = 1
		Dim fn, f, fso 
		Dim l, m
		
		Rem -- Get the name of the text file from the context object
		fn = Context("TextFileName")
			
		Rem -- Count the pages of the text file. Each page is separated
		Rem -- by a formfeed character chr(12).
		Set fso = CreateObject("Scripting.FilesystemObject")
		Set f = fso.OpenTextFile(fn, ForReading)
		While Not f.AtEndOfStream
			Rem -- Read a line from the text file
			i = 0
			l = trim(f.ReadLine())
			m = m & l & vbCrLf
		Wend
		f.Close
			
		Rem -- We extract the invoice number here
		Set fso = CreateObject("Scripting.FilesystemObject")
		Set f = fso.OpenTextFile(fn, ForReading)
		While Not f.AtEndOfStream
			Rem -- Read line-by-line from the text inside the pdf
			l = trim(f.ReadLine())
				
			Rem -- for invoices in german
			a = Mid(l,1,12)
			If a = "Rechnung Nr." Then
				invoice_number = trim(Mid(l,13,13))
			End If
				
			Rem -- for invoices in english
			a = Mid(l,1,11)
			If a = "Invoice No." Then
				invoice_number = trim(Mid(l,12,13))
			End If
		Wend
		f.Close
			
		Rem -- Clean up
		Set fso = Nothing
			
		Rem -- ZUGFeRD XML Files are expected under C:\einvoices 
		Rem -- Filename is invoice number (Example: 2021-09-1001.xml etc.)
		Rem -- That's the reason why we need the invoice number from print data.
		Rem -- We store it in a global var invoice_number
					
    End Sub
	
	Sub OnSuccess()
		global_success = true
	End Sub
	
	Sub OnAfterPrint()
		Dim myOutputFileName
		Dim objShell
		Dim fso
		Dim myOutputFileBaseName
		Dim MyAbsolutPDFOutputPath
		Dim myZUGFeRDOutputPath
			
		If global_success Then
			myOutputFileName = Context("OutputFileName")
								
			Set fso = CreateObject("Scripting.FilesystemObject")
			MyAbsolutPDFOutputPath = fso.GetParentFolderName(myOutputFileName) & "\"
			myOutputFileBaseName = fso.GetBaseName(myOutputFileName) 
			myZUGFeRDOutputPath = MyAbsolutPDFOutputPath & myOutputFileBaseName & ".zugferd.pdf"
				
			Rem -- After printing the pdf, we here attach the well formed XML ZUGFeRD File
			Rem -- to the printed PDF/A1b file by using the free to use JAVA based OpenSource ZUGFeRD API Mustang-CLI
			Rem -- More about Mustang visit: https://www.mustangproject.org
				
			Rem -- Place >>Mustang-CLI-x.x.x.jar<< to 7-PDF Printer's InstallRoot!
			
			Rem -- IMPORTANT!!
			Rem -- If you are using another build number then 2.3.3,
			Rem -- you must change this above to your version build.
			
			Rem -- Default Path to InstallRoot of 7-PDF Printer
			Rem -- C:\Program Files\7-PDF\PDF Printer\
				
			Rem -- You can use a OpenJDK (GPL). To download, visit the Microsoft Website:
			Rem -- https://docs.microsoft.com/en-us/java/openjdk/download
			Rem -- Run the setup without any changes! 
			Rem -- We have used "microsoft-jdk-17.0.1.12.1-windows-x64.msi"
			
			Rem -- IMPORTANT!!
			Rem -- Note, to change the path and build version to java.exe
			Rem -- if necessary, here on the next following lines!
				
			Rem -- Run command in hidden mode
			With CreateObject("WScript.Shell")
				.Run """C:\Program Files\Microsoft\jdk-17.0.1.12-hotspot\bin\java.exe"" -jar ""C:\Program Files\7-PDF\PDF Printer\Mustang-CLI-2.3.3.jar"" --action combine --source """ & myOutputFileName & """ --out """ & myZUGFeRDOutputPath & """ --source-xml ""C:\einvoices\"&invoice_number&".xml"" --format ""zf"" --version ""2"" --profile ""e""", 0, True
			End With
				
			If delMyOriginPDF = "yes" then
				If fso.FileExists(myOutputFileName) then  
					fso.DeleteFile myOutputFileName
				End If
			End If
				
			If RenameZUGFeRDPDFToOriginPDFName = "yes" then
				If fso.FileExists(myOutputFileName) then 
					fso.DeleteFile myOutputFileName
					fso.MoveFile myZUGFeRDOutputPath, myOutputFileName
				Else
					fso.MoveFile myZUGFeRDOutputPath, myOutputFileName
				End If
			End If
					
			Rem -- Open System Default PDF Viewer with ShellExecute API
			Rem -- This will show the final greated ZUGFeRD PDF file.
			If showmypdf = "yes" then
				If RenameZUGFeRDPDFToOriginPDFName = "yes" then
					Set objShell = CreateObject("Shell.Application")
					objShell.ShellExecute myOutputFileName, "", "", "open", 1
				Else
					Set objShell = CreateObject("Shell.Application")
					objShell.ShellExecute myZUGFeRDOutputPath, "", "", "open", 1
				End If
			End If
				
			Set fso = Nothing
					
		End If
			
	End Sub
